#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-eval-plugin
version:              2.3.0.0
visibility:           public
id:                   hls-eval-plugin-2.3.0.0-GHFSic56p7mGFexGhbrY5I
key:                  hls-eval-plugin-2.3.0.0-GHFSic56p7mGFexGhbrY5I
license:              Apache-2.0
maintainer:
    https://github.com/haskell/haskell-language-server/contributors

author:
    https://github.com/haskell/haskell-language-server/contributors

synopsis:             Eval plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  70d6401bb8d3d7225e196d84d756c4c5
exposed:              True
exposed-modules:      Ide.Plugin.Eval Ide.Plugin.Eval.Types
hidden-modules:
    Ide.Plugin.Eval.Code Ide.Plugin.Eval.CodeLens
    Ide.Plugin.Eval.Config Ide.Plugin.Eval.GHC
    Ide.Plugin.Eval.Parse.Comments Ide.Plugin.Eval.Parse.Option
    Ide.Plugin.Eval.Rules Ide.Plugin.Eval.Util

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-eval-plugin-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-eval-plugin-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-eval-plugin-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-eval-plugin
hs-libraries:         HShls-eval-plugin-2.3.0.0-GHFSic56p7mGFexGhbrY5I
depends:
    Diff-0.5-KXelOT1A7XYBE1m5Mxpw7N
    QuickCheck-2.15.0.1-KbEu55Yn4v1JAMl6aurZE0
    aeson-2.2.1.0-IFj7FSeQ5R79PZnh3ksXrW base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz deepseq-1.4.8.1
    directory-1.3.8.5 dlist-1.0-B7D1vsARFiIHVaGk5CGbYO
    extra-1.7.16-COAoMleqge7G93j2zK3Os3 filepath-1.4.300.1 ghc-9.6.6
    ghc-boot-th-9.6.6 ghc-paths-0.1.0.12-JSGGj7CcxjZ2Iy0LlOG5cZ
    ghcide-2.3.0.0-roa2yceaWZInAuFLFv0WZ
    hashable-1.4.7.0-JuZCUcgZ6993MAquoa2cCW
    hls-graph-2.3.0.0-1z80l9DPzvC9twCkDucgLx
    hls-plugin-api-2.3.0.0-CCML0HyRmic6Eq7DkGPRu6
    lens-5.3.4-9D2yk6aQnpf3ebTPLPYG20
    lsp-2.2.0.0-1GTZZafkEuOHztrSNMPAEV
    lsp-types-2.0.2.0-2OjFpOvQhFj49peoG26N8A
    megaparsec-9.7.0-2gGX6HbUqVZ7B58w8DDw7p mtl-2.3.1
    parser-combinators-1.3.1-8aQ8dKOwDVmFxT1S1WvW6m
    pretty-simple-4.1.4.0-1ROAKrBN4xO5WL4HZFyvkL
    safe-exceptions-0.1.7.4-BGySaU8uJj39VCxO5h0Lp3 text-2.0.2
    time-1.12.2 transformers-0.6.1.0
    unliftio-0.2.25.1-FRGz7PceS9EF7fvbKOBYVe
    unordered-containers-0.2.20.1-24qNbjJ9xXJll0vtFCYfq

haddock-interfaces:
    /usr/share/doc/haskell-hls-eval-plugin/html/hls-eval-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-eval-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

